aboutsummaryrefslogtreecommitdiffhomepage
path: root/scripts/ci/windows
diff options
context:
space:
mode:
authorGravatar philwo <philwo@google.com>2017-04-28 17:51:22 +0200
committerGravatar Vladimir Moskva <vladmos@google.com>2017-04-28 18:33:30 +0200
commit6f7066e3112315d259c00d5b68330a326391ec31 (patch)
treeb0f860baefa4d74dccc5cd4db0c58c78e18536ef /scripts/ci/windows
parent2541fd93287ff135c3348a3986cea7dfc8444f71 (diff)
Bundled JDK changes for the release process. This is a fixed version
that should not break CI this time... - Make the default Bazel release artifacts include the bundled JDK. - Create additional Bazel release artifacts without a bundled JDK. Tested by running "bazel build //scripts/..." in a clean checkout and one with this patch in, then diffing the entire bazel-out folder and manually inspecting the resulting files (zips, tar.gz, deb, rpm) to make sure that they contain the right files. Looks all good now, so let's try again. PiperOrigin-RevId: 154544164
Diffstat (limited to 'scripts/ci/windows')
-rwxr-xr-xscripts/ci/windows/compile_windows.sh10
1 files changed, 6 insertions, 4 deletions
diff --git a/scripts/ci/windows/compile_windows.sh b/scripts/ci/windows/compile_windows.sh
index 802edaeeaa..4168f551b5 100755
--- a/scripts/ci/windows/compile_windows.sh
+++ b/scripts/ci/windows/compile_windows.sh
@@ -48,11 +48,13 @@ fi
${BOOTSTRAP_BAZEL} --bazelrc=${BAZELRC:-/dev/null} --nomaster_bazelrc build \
--embed_label=${release_label} --stamp \
${MSVC_OPTS} \
- //src:bazel
+ //src:bazel //src:bazel_with_jdk
-
-# Copy the resulting artifact.
+# Copy the resulting artifacts.
mkdir -p output/ci
-cp bazel-bin/src/bazel output/ci/bazel${MSVC_LABEL}-$(get_full_release_name).exe
+cp bazel-bin/src/bazel output/ci/bazel${MSVC_LABEL}-$(get_full_release_name)-without-jdk.exe
+cp bazel-bin/src/bazel_with_jdk output/ci/bazel${MSVC_LABEL}-$(get_full_release_name).exe
cp bazel-bin/src/bazel output/bazel.exe
+zip -j output/ci/bazel${MSVC_LABEL}-$(get_full_release_name)-without-jdk.zip output/bazel.exe
+cp -f bazel-bin/src/bazel_with_jdk output/bazel.exe
zip -j output/ci/bazel${MSVC_LABEL}-$(get_full_release_name).zip output/bazel.exe